@@ -7,7 +7,7 @@ use DBI;
 
 # Define Version :
 # ----------------------------------------------------------------
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # Create Module for Connection MySQL Database :
 # ------------------------------------------------------------------------
@@ -53,7 +53,10 @@ sub mysql {
     # Define database conection :
     # ----------------------------------------------------------------
     my $dsn = 'DBI:mysql:database='.$db_name.';host='.$db_host;
-    $dbh = DBI->connect($dsn, $db_user, $db_pass, {RaiseError => 1});
+    $dbh = DBI->connect($dsn, $db_user, $db_pass, {
+            RaiseError => 0,
+            PrintError => 0,
+        });
 
     # Return Result :
     # ----------------------------------------------------------------
